@@ -10,7 +10,6 @@ resource_involvement_resource_activity <- function(eventlog) {
 		summarize() %>%
 		summarize("absolute" = n_distinct(!!case_id_(eventlog))) %>%
 		ungroup() %>%
-		mutate(relative = absolute/n_cases(eventlog)) %>%
-		arrange(desc(absolute))
+		mutate(relative = absolute/n_cases(eventlog))
 
 }
