@@ -6,6 +6,5 @@ resource_specialisation_resource <- function(eventlog) {
 		group_by(!!resource_id_(eventlog), !!activity_id_(eventlog)) %>%
 		summarize() %>%
 		summarize(absolute = n()) %>%
-		mutate(relative = absolute/n_activities(eventlog)) %>%
-		arrange(-absolute)
+		mutate(relative = absolute/n_activities(eventlog))
 	}
