@@ -3,7 +3,8 @@ start_activities_resource <- function(eventlog) {
 	absolute <- NULL
 	relative <- NULL
 	eventlog %>%
-		group_by_case() %>%
+		as.data.frame() %>%
+		group_by(!!case_id_(eventlog)) %>%
 		arrange(!!as.symbol(timestamp(eventlog)), .order) %>%
 		summarize(!!as.symbol(activity_id(eventlog)) := first(!!as.symbol(activity_id(eventlog))),
 				  !!as.symbol(resource_id(eventlog)) := first(!!as.symbol(resource_id(eventlog)))) %>%
@@ -12,7 +13,7 @@ start_activities_resource <- function(eventlog) {
 		arrange(desc(absolute)) %>%
 		mutate(relative = absolute/n_cases(eventlog),
 			   cum_sum = cumsum(relative)) %>%
-		arrange(!!activity_id_(eventlog))
+		arrange(!!resource_id_(eventlog))
 
 
 }
